@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-command-manager.c,v 1.6 2004/01/01 22:54:10 chpe Exp $
+ *  $Id: ephy-command-manager.c,v 1.7 2004/02/20 11:49:42 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,7 +36,7 @@ ephy_command_manager_get_type (void)
 	{
 		static const GTypeInfo our_info =
 		{
-			sizeof (EphyCommandManagerIFace),
+			sizeof (EphyCommandManagerIface),
 			ephy_command_manager_base_init,
 			NULL,
 		};
@@ -60,7 +60,7 @@ ephy_command_manager_base_init (gpointer g_class)
 		g_signal_new ("command_changed",
 			      EPHY_TYPE_COMMAND_MANAGER,
 			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (EphyCommandManagerIFace, command_changed),
+			      G_STRUCT_OFFSET (EphyCommandManagerIface, command_changed),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING,
 			      G_TYPE_NONE,
@@ -75,7 +75,7 @@ void
 ephy_command_manager_do_command (EphyCommandManager *manager,
 				 const char *command)
 {
-	EphyCommandManagerIFace *iface = EPHY_COMMAND_MANAGER_GET_IFACE (manager);
+	EphyCommandManagerIface *iface = EPHY_COMMAND_MANAGER_GET_IFACE (manager);
 	iface->do_command (manager, command);
 }
 
@@ -83,6 +83,6 @@ gboolean
 ephy_command_manager_can_do_command (EphyCommandManager *manager,
 					const char *command)
 {
-	EphyCommandManagerIFace *iface = EPHY_COMMAND_MANAGER_GET_IFACE (manager);
+	EphyCommandManagerIface *iface = EPHY_COMMAND_MANAGER_GET_IFACE (manager);
 	return iface->can_do_command (manager, command);
 }
