@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-persist.c,v 1.10 2004/01/14 11:39:31 chpe Exp $
+ *  $Id: ephy-embed-persist.c,v 1.12 2004/02/29 13:25:18 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,7 +50,7 @@ struct EphyEmbedPersistPrivate
 	char *fc_title;
 	char *persist_key;
 	EphyEmbed *embed;
-	int max_size;
+	long max_size;
 	EmbedPersistFlags flags;
 	GtkWindow *fc_parent;
 };
@@ -63,9 +63,9 @@ static GObjectClass *parent_class = NULL;
 GType
 ephy_embed_persist_get_type (void)
 {
-       static GType ephy_embed_persist_type = 0;
+       static GType type = 0;
 
-	if (ephy_embed_persist_type == 0)
+	if (type == 0)
 	{
 		static const GTypeInfo our_info =
 		{
@@ -80,12 +80,12 @@ ephy_embed_persist_get_type (void)
 			(GInstanceInitFunc) ephy_embed_persist_init
 		};
 
-		ephy_embed_persist_type = g_type_register_static (G_TYPE_OBJECT,
-								  "EphyEmbedPersist",
-								  &our_info, 0);
+		type = g_type_register_static (G_TYPE_OBJECT,
+					       "EphyEmbedPersist",
+					       &our_info, 0);
 	}
 
-	return ephy_embed_persist_type;
+	return type;
 }
 
 void
@@ -135,7 +135,7 @@ ephy_embed_persist_set_flags (EphyEmbedPersist *persist,
 
 void
 ephy_embed_persist_set_max_size (EphyEmbedPersist *persist,
-				 int value)
+				 long value)
 {
 	g_return_if_fail (EPHY_IS_EMBED_PERSIST (persist));
 
@@ -250,7 +250,7 @@ ephy_embed_persist_set_property (GObject *object,
 			ephy_embed_persist_set_flags (persist, g_value_get_int (value));
 			break;
 		case PROP_MAX_SIZE:
-			ephy_embed_persist_set_max_size (persist, g_value_get_int (value));
+			ephy_embed_persist_set_max_size (persist, g_value_get_long (value));
 			break;
 		case PROP_PERSISTKEY:
 			ephy_embed_persist_set_persist_key (persist, g_value_get_string (value));
@@ -287,7 +287,7 @@ ephy_embed_persist_get_property (GObject *object,
 			g_value_set_int (value, ephy_embed_persist_get_flags (persist));
 			break;
 		case PROP_MAX_SIZE:
-			g_value_set_int (value, ephy_embed_persist_get_max_size (persist));
+			g_value_set_long (value, ephy_embed_persist_get_max_size (persist));
 			break;
 		case PROP_PERSISTKEY:
 			g_value_set_string (value, ephy_embed_persist_get_persist_key (persist));
@@ -310,7 +310,7 @@ ephy_embed_persist_init (EphyEmbedPersist *persist)
 	persist->priv->fc_title = NULL;
 	persist->priv->fc_parent = NULL;
 	persist->priv->flags = 0;
-	persist->priv->max_size = 0;
+	persist->priv->max_size = -1;
 	persist->priv->persist_key = NULL;
 }
 
@@ -349,6 +349,14 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 		      g_cclosure_marshal_VOID__VOID,
 		      G_TYPE_NONE,
 		      0);
+	g_signal_new ("cancelled",
+		      G_OBJECT_CLASS_TYPE (object_class),
+		      G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (EphyEmbedPersistClass, cancelled),
+		      NULL, NULL,
+		      g_cclosure_marshal_VOID__VOID,
+		      G_TYPE_NONE,
+		      0);
 
 	g_object_class_install_property (object_class,
 					 PROP_DEST,
@@ -395,11 +403,11 @@ ephy_embed_persist_class_init (EphyEmbedPersistClass *klass)
 
 	g_object_class_install_property (object_class,
 					 PROP_MAX_SIZE,
-					 g_param_spec_int    ("max_size",
+					 g_param_spec_long   ("max_size",
 							      "Maxsize",
 							      "Maximum size of the file",
 							      0,
-							      G_MAXINT,
+							      G_MAXLONG,
 							      0,
 							      G_PARAM_READWRITE));
 
