@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.21 2004/02/20 22:44:44 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.22.4.1 2004/04/28 18:09:59 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -633,6 +633,8 @@ nsresult EphyBrowser::GetPageDescriptor(nsISupports **aPageDescriptor)
 
 nsresult EphyBrowser::GetDocumentUrl (nsCString &url)
 {
+	if (!mDOMWindow) return NS_ERROR_FAILURE;
+
 	nsCOMPtr<nsIDOMDocument> DOMDocument;
 	mDOMWindow->GetDocument (getter_AddRefs(DOMDocument));
 	NS_ENSURE_TRUE (DOMDocument, NS_ERROR_FAILURE);
@@ -865,7 +867,8 @@ nsresult EphyBrowser::GetCommandState (const char *command, PRBool *enabled)
 nsresult EphyBrowser::GetDocumentHasModifiedForms (nsIDOMDocument *aDomDoc, PRUint32 *aNumTextFields, PRBool *aHasTextArea)
 {
 	nsCOMPtr<nsIDOMHTMLDocument> htmlDoc = do_QueryInterface(aDomDoc);
-	NS_ENSURE_TRUE (htmlDoc, NS_ERROR_FAILURE);
+	/* it's okay not to be a HTML doc (happens for XUL documents, like about:config) */
+	if (!htmlDoc) return NS_OK;
 
 	nsCOMPtr<nsIDOMHTMLCollection> forms;
 	htmlDoc->GetForms (getter_AddRefs (forms));
