@@ -15,14 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.7 2003/11/19 19:19:56 chpe Exp $
+ *  $Id: EphyBrowser.h,v 1.10 2004/01/27 12:48:55 marco Exp $
  */
 
 #ifndef EPHY_BROWSER_H
 #define EPHY_BROWSER_H
 
 #include "ephy-encodings.h"
+#include "ephy-embed.h"
 
+#include "nsIDOMEventListener.h"
 #include "nsIDocShell.h"
 #include "nsIWebNavigation.h"
 #include "nsIWebPageDescriptor.h"
@@ -38,7 +40,38 @@
 
 #include "nsIPrintSettings.h"
 
-class EphyEventListener;
+class EphyEventListener : public nsIDOMEventListener
+{
+public:
+	EphyEventListener();
+	virtual ~EphyEventListener();
+
+	nsresult Init(EphyEmbed *aOwner);
+
+	NS_DECL_ISUPPORTS
+
+	// nsIDOMEventListener
+
+	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent) = 0;
+
+protected:
+	EphyEmbed *mOwner;
+};
+
+class EphyFaviconEventListener : public EphyEventListener
+{
+public:
+	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
+
+private:
+	nsresult HandleFaviconLink (nsIDOMNode *node);
+};
+
+class EphyPopupEventListener : public EphyEventListener
+{
+public:
+	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
+};
 
 class EphyBrowser
 {
@@ -86,6 +119,8 @@ public:
 	nsresult GetDocumentUrl (nsCString &url);
 	nsresult GetTargetDocumentUrl (nsCString &url);
 
+	nsresult GetHasModifiedForms (PRBool *modified);
+
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
 
 private:
@@ -93,7 +128,9 @@ private:
 	nsCOMPtr<nsIWebProgressListener> mProgress;
 	nsCOMPtr<nsIDOMEventReceiver> mEventReceiver;
 	nsCOMPtr<nsIDOMWindow> mDOMWindow;
-	EphyEventListener *mEventListener;
+	EphyFaviconEventListener *mFaviconEventListener;
+	EphyPopupEventListener *mPopupEventListener;
+	PRBool mInitialized;
 
 	nsresult GetListener (void);
 	nsresult AttachListeners (void);
@@ -101,6 +138,7 @@ private:
 	nsresult SetZoomOnDocshell (float aZoom, nsIDocShell *DocShell);
 	nsresult GetSHistory (nsISHistory **aSHistory);
 	nsresult GetContentViewer (nsIContentViewer **aViewer);
+	nsresult GetDocumentHasModifiedForms (nsIDOMDocument *aDomDoc, PRUint32 *aNumTextFields, PRBool *aHasTextArea);
 };
 
 #endif
