@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.26 2004/02/21 19:59:01 chpe Exp $
+ *  $Id: EventContext.cpp,v 1.26.4.1 2004/03/29 15:04:12 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -394,6 +394,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 			if (tag.EqualsIgnoreCase("a"))
 			{
 				nsAutoString tmp;
+				nsAutoString substr;
 
 				rv = GatherTextUnder (node, tmp);
 				if (NS_SUCCEEDED(rv))
@@ -401,25 +402,15 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 
 				nsCOMPtr <nsIDOMHTMLAnchorElement> anchor =
 					do_QueryInterface(node);
-				rv = anchor->GetHref (tmp);
-				if (NS_FAILED(rv))
-					return NS_ERROR_FAILURE;
 
-				nsCOMPtr<nsIURI> uri;
-				NS_NewURI (getter_AddRefs (uri), tmp);
-				if (!uri) return NS_ERROR_FAILURE;
-			
-				nsresult rv;
-				nsCAutoString scheme;
-				rv = uri->GetScheme (scheme);
-				if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
-
-				if (scheme.EqualsIgnoreCase("mailto"))
+				anchor->GetHref (tmp);
+				substr.Assign (Substring (tmp, 0, 7));
+				if (substr.EqualsIgnoreCase("mailto:"))
 				{
 					info->context |= EMBED_CONTEXT_EMAIL_LINK;
 					const nsAString &address = Substring(tmp, 7, tmp.Length()-7);
 					SetStringProperty ("email", address);
-				}	
+				}
 				
 				if (anchor && !tmp.IsEmpty()) 
 				{
