@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.cpp,v 1.21 2004/01/10 11:19:52 chpe Exp $
+ *  $Id: FilePicker.cpp,v 1.26.4.3 2004/04/13 19:32:45 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -63,10 +63,12 @@ NS_IMPL_ISUPPORTS1(GFilePicker, nsIFilePicker)
 
 GFilePicker::GFilePicker()
 {
-	LOG ("GFilePicker constructor")
+	LOG ("GFilePicker ctor (%p)", this)
 
 	mDialog = EPHY_FILE_CHOOSER (g_object_new (EPHY_TYPE_FILE_CHOOSER, NULL));
 
+	g_object_add_weak_pointer (G_OBJECT (mDialog), (gpointer *) &mDialog);
+
 	ephy_file_chooser_set_persist_key (mDialog, CONF_STATE_UPLOAD_DIR);
 
 	mMode = nsIFilePicker::modeOpen;
@@ -74,10 +76,11 @@ GFilePicker::GFilePicker()
 
 GFilePicker::~GFilePicker()
 {
-	LOG ("GFilePicker destructor")
+	LOG ("GFilePicker dtor (%p)", this)
 
 	if (mDialog)
 	{
+		g_object_remove_weak_pointer (G_OBJECT (mDialog), (gpointer *) &mDialog);
 		gtk_widget_destroy (GTK_WIDGET (mDialog));
 	}
 }
@@ -85,10 +88,11 @@ GFilePicker::~GFilePicker()
 /* void init (in nsIDOMWindowInternal parent, in wstring title, in short mode); */
 NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *title, PRInt16 mode)
 {
-	nsCOMPtr<nsIDOMWindow> dw = do_QueryInterface (parent);
-	if (dw)
+	LOG ("GFilePicker::Init")
+
+	if (parent)
 	{
-		GtkWidget *pwin = MozillaFindGtkParent (dw);
+		GtkWidget *pwin = MozillaFindGtkParent (parent);
 
 		gtk_window_set_transient_for (GTK_WINDOW (mDialog), GTK_WINDOW (pwin));
 	}
@@ -99,40 +103,47 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindowInternal *parent, const PRUnichar *t
 
 	switch (mode)
 	{
-		case nsIFilePicker::modeOpen:
 		case nsIFilePicker::modeGetFolder:
+			gtk_file_chooser_set_action (GTK_FILE_CHOOSER (mDialog),
+						     GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
+			
+			gtk_dialog_add_buttons (GTK_DIALOG (mDialog),
+						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+						NULL);
+			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), GTK_RESPONSE_ACCEPT);
+			break;
+
 		case nsIFilePicker::modeOpenMultiple:
+			gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (mDialog), TRUE);
+			/* fallthrough */			
+		case nsIFilePicker::modeOpen:
 			gtk_file_chooser_set_action (GTK_FILE_CHOOSER (mDialog),
 						     GTK_FILE_CHOOSER_ACTION_OPEN);
 
 			gtk_dialog_add_buttons (GTK_DIALOG (mDialog),
 						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-						GTK_STOCK_OPEN, EPHY_RESPONSE_OPEN,
+						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 						NULL);
-			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), EPHY_RESPONSE_OPEN);
+			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), GTK_RESPONSE_ACCEPT);
 
 			break;
+
 		case nsIFilePicker::modeSave:
 			gtk_file_chooser_set_action (GTK_FILE_CHOOSER (mDialog),
 						     GTK_FILE_CHOOSER_ACTION_SAVE);
 	
 			gtk_dialog_add_buttons (GTK_DIALOG (mDialog),
 						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-						GTK_STOCK_SAVE, EPHY_RESPONSE_SAVE,
+						GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
 						NULL);
-			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), EPHY_RESPONSE_SAVE);
+			gtk_dialog_set_default_response (GTK_DIALOG (mDialog), GTK_RESPONSE_ACCEPT);
 			break;
 		default:
 			g_assert_not_reached ();
 			break;
 	}
 
-	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (mDialog),
-					      mode == nsIFilePicker::modeOpenMultiple);
-
-	gtk_file_chooser_set_folder_mode (GTK_FILE_CHOOSER (mDialog),
-					  mode == nsIFilePicker::modeGetFolder);
-
 	return NS_OK;
 }
 
@@ -144,6 +155,8 @@ NS_IMETHODIMP GFilePicker::AppendFilters(PRInt32 filterMask)
 
 	// FIXME: use filters with mimetypes instead of extensions
 
+	LOG ("GFilePicker::AppendFilters mask=%d", filterMask)
+
 	if (filterMask & nsIFilePicker::filterAll)
 	{
 		AppendFilter (NS_ConvertUTF8toUCS2 (_("All files")).get(),
@@ -181,15 +194,27 @@ NS_IMETHODIMP GFilePicker::AppendFilters(PRInt32 filterMask)
 /* void appendFilter (in wstring title, in wstring filter); */
 NS_IMETHODIMP GFilePicker::AppendFilter(const PRUnichar *title, const PRUnichar *filter)
 {
-	GtkFileFilter *filth;
+	LOG ("GFilePicker::AppendFilter title '%s' for '%s'",
+	     NS_ConvertUCS2toUTF8 (title).get(),
+	     NS_ConvertUCS2toUTF8 (filter).get())
 
-	filth = gtk_file_filter_new ();
+	nsCAutoString pattern = NS_ConvertUCS2toUTF8 (filter);
+	pattern.StripWhitespace();
+
+	char **patterns = g_strsplit (pattern.get(), ";", -1);
+
+	GtkFileFilter *filth = gtk_file_filter_new ();
+
+	for (int i = 0; patterns[i] != NULL; i++)
+	{
+		gtk_file_filter_add_pattern (filth, patterns[i]);
+	}
 
 	gtk_file_filter_set_name (filth, NS_ConvertUCS2toUTF8(title).get());
-	gtk_file_filter_add_pattern (filth, NS_ConvertUCS2toUTF8(filter).get());
-
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (mDialog), filth);
 
+	g_strfreev (patterns);
+
 	return NS_OK;
 }
 
@@ -198,11 +223,14 @@ NS_IMETHODIMP GFilePicker::GetDefaultString(PRUnichar **aDefaultString)
 {
 	char *filename, *converted;
 
+	LOG ("GFilePicker::GetDefaultString")
+
 	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (mDialog));
 	if (filename != NULL)
 	{
 		converted = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
-	
+
+		/* FIXME: when can depend on moz >= 1.6, use CopyUTF8toUCS2 here */
 		*aDefaultString = ToNewUnicode (NS_ConvertUTF8toUCS2 (converted));
 	
 		g_free (filename);
@@ -214,6 +242,9 @@ NS_IMETHODIMP GFilePicker::GetDefaultString(PRUnichar **aDefaultString)
 
 NS_IMETHODIMP GFilePicker::SetDefaultString(const PRUnichar *aDefaultString)
 {
+	LOG ("GFilePicker::SetDefaultString to %s",
+	     NS_ConvertUCS2toUTF8 (aDefaultString).get())
+
 	if (aDefaultString)
 	{
 		/* set_current_name takes UTF-8, not a filename */
@@ -228,29 +259,42 @@ NS_IMETHODIMP GFilePicker::SetDefaultString(const PRUnichar *aDefaultString)
 /* attribute wstring defaultExtension; */
 NS_IMETHODIMP GFilePicker::GetDefaultExtension(PRUnichar **aDefaultExtension)
 {
+	LOG ("GFilePicker::GetDefaultExtension")
+
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP GFilePicker::SetDefaultExtension(const PRUnichar *aDefaultExtension)
 {
+	LOG ("GFilePicker::SetDefaultExtension to %s",
+	     NS_ConvertUCS2toUTF8(aDefaultExtension).get())
+
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 /* attribute long filterIndex; */
 NS_IMETHODIMP GFilePicker::GetFilterIndex(PRInt32 *aFilterIndex)
 {
+	LOG ("GFilePicker::GetFilterIndex")
+
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP GFilePicker::SetFilterIndex(PRInt32 aFilterIndex)
 {
+	LOG ("GFilePicker::SetFilterIndex index=%d", aFilterIndex)
+
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 /* attribute nsILocalFile displayDirectory; */
 NS_IMETHODIMP GFilePicker::GetDisplayDirectory(nsILocalFile **aDisplayDirectory)
 {
-	char *dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (mDialog));
+	char *dir;
+
+	LOG ("GFilePicker::GetDisplayDirectory")
+
+	dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (mDialog));
 
 	if (dir != NULL)
 	{
@@ -269,6 +313,8 @@ NS_IMETHODIMP GFilePicker::SetDisplayDirectory(nsILocalFile *aDisplayDirectory)
 	nsCAutoString dir;
 	aDisplayDirectory->GetNativePath (dir);
 
+	LOG ("GFilePicker::SetDisplayDirectory to %s", dir.get())
+
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (mDialog),
 					     dir.get());
 
@@ -278,7 +324,11 @@ NS_IMETHODIMP GFilePicker::SetDisplayDirectory(nsILocalFile *aDisplayDirectory)
 /* readonly attribute nsILocalFile file; */
 NS_IMETHODIMP GFilePicker::GetFile(nsILocalFile **aFile)
 {
-	char *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (mDialog));
+	char *filename;
+
+	LOG ("GFilePicker::GetFile")
+
+	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (mDialog));
 
 	if (filename != NULL)
 	{
@@ -295,6 +345,8 @@ NS_IMETHODIMP GFilePicker::GetFile(nsILocalFile **aFile)
 /* readonly attribute nsIFileURL fileURL; */
 NS_IMETHODIMP GFilePicker::GetFileURL(nsIFileURL **aFileURL)
 {
+	LOG ("GFilePicker::GetFileURL")
+
 	nsCOMPtr<nsILocalFile> file;
 	GetFile (getter_AddRefs(file));
 	NS_ENSURE_TRUE (file, NS_ERROR_FAILURE);
@@ -312,37 +364,43 @@ NS_IMETHODIMP GFilePicker::GetFiles(nsISimpleEnumerator * *aFiles)
 	// Not sure if we need to implement it at all, it's used nowhere
 	// in mozilla, but I guess a javascript might call it?
 
+	LOG ("GFilePicker::GetFiles")
+
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 /* short show (); */
 NS_IMETHODIMP GFilePicker::Show(PRInt16 *_retval)
 {
+	LOG ("GFilePicker::Show")
+
 	gtk_window_set_modal (GTK_WINDOW (mDialog), TRUE);
 
 	gtk_widget_show (GTK_WIDGET (mDialog));
 
-	int response = gtk_dialog_run (GTK_DIALOG (mDialog));
+	int response;
+	char *filename = NULL;
 
-	switch (response)
+	do
 	{
-		case EPHY_RESPONSE_OPEN:
-		case EPHY_RESPONSE_SAVE:
-			*_retval = nsIFilePicker::returnOK;
-			break;
-		default:
-			*_retval = nsIFilePicker::returnCancel;
-			break;
+		response = gtk_dialog_run (GTK_DIALOG (mDialog));
+
+		g_free (filename);
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (mDialog));
+
+		LOG ("GFilePicker::Show response=%d, filename=%s", response, filename)
 	}
+	while (response == GTK_RESPONSE_ACCEPT &&
+	       mMode == nsIFilePicker::modeSave &&
+	       !ephy_gui_confirm_overwrite_file (GTK_WIDGET (mDialog), filename));
 
-	char *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (mDialog));
+	gtk_widget_hide (GTK_WIDGET (mDialog));
 
-	if (filename == NULL)
+	if (response == GTK_RESPONSE_ACCEPT && filename != NULL)
 	{
-		*_retval = nsIFilePicker::returnCancel;
+		*_retval = nsIFilePicker::returnOK;
 	}
-	else if (mMode == nsIFilePicker::modeSave
-		 && ephy_gui_confirm_overwrite_file (GTK_WIDGET (mDialog), filename) == FALSE)
+	else
 	{
 		*_retval = nsIFilePicker::returnCancel;
 	}
