@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.169.4.3 2004/04/18 10:29:03 chpe Exp $
+ *  $Id: ephy-window.c,v 1.169.4.4 2004/04/26 22:47:22 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -667,6 +667,19 @@ ephy_window_delete_event_cb (GtkWidget *widget, GdkEvent *event, EphyWindow *win
 	GList *tabs, *l;
 	gboolean modified = FALSE;
 
+	/* Workaround a crash when closing a window while in print preview mode. See
+	 * mozilla bug #241809
+	 */
+	if (window->priv->mode == EPHY_WINDOW_MODE_PRINT_PREVIEW)
+	{
+		EphyEmbed *embed;
+
+		embed = ephy_window_get_active_embed (window);
+		ephy_embed_print_preview_close (embed);
+
+		ephy_window_set_print_preview (window, FALSE);
+	}
+
 	tabs = ephy_window_get_tabs (window);
 	for (l = tabs; l != NULL; l = l->next)
 	{
